@@ -32,6 +32,7 @@ import tensorflow as tf
 from tensorflow.keras import backend, layers, models, optimizers
 
 from . import dataset, train, weights
+from .train import SaveWeightsCallback
 from ..common.base_class import BaseClass
 from ..model import yolov4
 
@@ -84,10 +85,21 @@ class YOLOv4(BaseClass):
         if weights_type == "yolo":
             weights.load_weights(self.model, weights_path, tiny=self.tiny)
         elif weights_type == "tf":
-            self.model.load_weights(weights_path, by_name=True)
+            self.model.load_weights(weights_path)
 
         self._has_weights = True
 
+    def save_weights(self, weights_path: str, weights_type: str = "tf"):
+        """
+        Usage:
+            yolo.save_weights("yolov4.weights", weights_type="yolo")
+            yolo.save_weights("checkpoints")
+        """
+        if weights_type == "yolo":
+            weights.save_weights(self.model, weights_path, tiny=self.tiny)
+        elif weights_type == "tf":
+            self.model.save_weights(weights_path)
+
     def save_as_tflite(
         self,
         tflite_path,
@@ -159,7 +171,9 @@ class YOLOv4(BaseClass):
         for candidate in candidates:
             grid_size = candidate.shape[1]
             _candidates.append(
-                tf.reshape(candidate, shape=(1, grid_size * grid_size * 3, -1))
+                tf.reshape(
+                    candidate[0], shape=(1, grid_size * grid_size * 3, -1)
+                )
             )
         candidates = np.concatenate(_candidates, axis=1)
 
@@ -244,25 +258,34 @@ class YOLOv4(BaseClass):
             ),
         )
 
-    def fit(self, data_set, epochs, verbose=1, callbacks=None):
-        # validation_split=0.,
-        # validation_data=None,
-        # shuffle=True,
-        # class_weight=None,
-        # sample_weight=None,
-        # initial_epoch=0,
-        # steps_per_epoch=None,
-        # validation_steps=None,
-        # validation_batch_size=None,
-        # validation_freq=1,
-        # max_queue_size=10,
-        # workers=1,
-        # use_multiprocessing=False
+    def fit(
+        self,
+        data_set,
+        epochs,
+        verbose=1,
+        callbacks=None,
+        validation_data=None,
+        initial_epoch=0,
+        validation_steps=None,
+        validation_freq=1,
+    ):
         self.model.fit(
             data_set,
+            batch_size=self.batch_size // self.subdivision,
             epochs=epochs,
             verbose=verbose,
             callbacks=callbacks,
-            batch_size=self.batch_size // self.subdivision,
+            validation_split=0.0,
+            validation_data=validation_data,
+            shuffle=True,
+            class_weight=None,
+            sample_weight=None,
+            initial_epoch=initial_epoch,
             steps_per_epoch=self.subdivision,
+            validation_steps=validation_steps,
+            validation_batch_size=None,
+            validation_freq=validation_freq,
+            max_queue_size=10,
+            workers=1,
+            use_multiprocessing=False,
         )
