@@ -59,18 +59,16 @@ class Dataset:
                 np.reshape(
                     np.stack(
                         np.meshgrid(
-                            (np.arange(self.grid_size[i]) + 0.5)
-                            / self.grid_size[i],
-                            (np.arange(self.grid_size[i]) + 0.5)
-                            / self.grid_size[i],
+                            (np.arange(_size) + 0.5) / _size,
+                            (np.arange(_size) + 0.5) / _size,
                         ),
                         axis=-1,
                     ),
-                    (1, self.grid_size[i], self.grid_size[i], 1, 2),
+                    (1, _size, _size, 1, 2),
                 ),
                 (1, 1, 1, 3, 1),
             ).astype(np.float32)
-            for i in range(len(self.grid_size))
+            for _size in self.grid_size
         ]
 
         self.dataset = self.load_dataset()
@@ -136,19 +134,12 @@ class Dataset:
         """
         ground_truth = [
             np.zeros(
-                (
-                    1,
-                    self.grid_size[i],
-                    self.grid_size[i],
-                    3,
-                    5 + self.num_classes,
-                ),
-                dtype=np.float32,
+                (1, _size, _size, 3, 5 + self.num_classes,), dtype=np.float32,
             )
-            for i in range(len(self.grid_size))
+            for _size in self.grid_size
         ]
-        for i in range(len(self.grid)):
-            ground_truth[i][..., 0:2] = self.grid[i]
+        for i, _grid in enumerate(self.grid):
+            ground_truth[i][..., 0:2] = _grid
 
         for bbox in bboxes:
             # [b_x, b_y, b_w, b_h, class_id]
@@ -211,11 +202,7 @@ class Dataset:
 
         @return image / 255, ground_truth
         """
-        image_path = dataset[0]
-        if not os.path.exists(image_path):
-            raise KeyError("{} does not exist".format(image_path))
-
-        image = cv2.imread(image_path)
+        image = cv2.imread(dataset[0])
         image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
         if self.dataset_type == "converted_coco":
             height, width, _ = image.shape
@@ -237,6 +224,20 @@ class Dataset:
 
         return resized_image, ground_truth
 
+    def _next_data(self):
+        for _ in range(5):
+            _dataset = self.dataset[self.count]
+
+            self.count += 1
+            if self.count == len(self.dataset):
+                np.random.shuffle(self.dataset)
+                self.count = 0
+
+            if os.path.exists(_dataset[0]):
+                return _dataset
+
+        raise KeyError("Image search failed five times in a row")
+
     def __iter__(self):
         self.count = 0
         np.random.shuffle(self.dataset)
@@ -245,25 +246,20 @@ class Dataset:
     def __next__(self):
         """
         @return image, ground_truth
-            ground_truth == (s_truth, m_truth, l_truth)
+            ground_truth == (s_truth, m_truth, l_truth) or (m_truth, l_truth)
         """
         if self.batch_size > 1:
             batch_x = []
             _batch_y = [[] for _ in range(len(self.grid_size))]
             for _ in range(self.batch_size):
-                x, y = self.preprocess_dataset(self.dataset[self.count])
+                x, y = self.preprocess_dataset(self._next_data())
                 batch_x.append(x)
                 for i, _y in enumerate(y):
                     _batch_y[i].append(_y)
             batch_x = np.concatenate(batch_x, axis=0)
             batch_y = [np.concatenate(b_y, axis=0) for b_y in _batch_y]
         else:
-            batch_x, batch_y = self.preprocess_dataset(self.dataset[self.count])
-
-        self.count += 1
-        if self.count == len(self.dataset):
-            np.random.shuffle(self.dataset)
-            self.count = 0
+            batch_x, batch_y = self.preprocess_dataset(self._next_data())
 
         return batch_x, batch_y
 
